% Function for reading ampl output files
% name is string filename, var is string variable name
% NOTE:
% when writing output to file in AMPL
% - write one variable at a time:
%   display x > out.out; y > out.out; DO NOT USE display x y;
% - set option display_1col 0 display_transpose -N display_width N;
%   where N is bigger than number of rows and columns in your variables

function x = amplRead(name,var)
fid = fopen(name,'r');

while(1)
tline = fgetl(fid);
if ~ischar(tline), error('variable not found'), end
% variabel postion if exists (exact name match)
m = regexp(tline,['\<' var '\>']);
if(~isempty(m))
	% found variable
	if(isempty(strfind(tline,'[')))
		% if '[' not found, it is a scalar
		arrayDim = 0;
	else
		numS=strfind(tline,'[');
		numE=strfind(tline,']');
		% check if it was transposed
		if(isempty(strfind(tline,'(tr)')))
			transpose = 0;
		else
			transpose = 1;
		end
		if(numE-numS == 2)
			arrayDim = 1;
		elseif(numE-numS == 4)
			% is a 2D matrix
			arrayDim = 2;
		elseif(numE-numS == 6)
			% is a 3D matrix
			arrayDim = 3;
			% index position which is held constant
			if(~isempty( strfind(tline(length(var)+2:end),'1') ) )
				indexConst = strfind(tline(length(var)+2:end),'1')/2;
			else
				indexConst = strfind(tline(length(var)+2:end),'0')/2;
			end
		else
			error('higher dimensional tensor');
		end
	end


	if(arrayDim == 0)
		x = str2num(tline(strfind(tline,'=')+1:end));
		fclose(fid);
		return;
	else
		row = 1;
		if(arrayDim ~= 1)
			% move one line down
			fgetl(fid);
		end
		if(arrayDim ==3)
			% the index of the constant index
			constIndNum = 1;
		end
		while(1)
			tline = fgetl(fid);
			if( ~isempty(regexp(tline,';')))
				% end loading the variable data if ';' found
				fclose(fid);
				return;
			end
			if( length(tline) < 2 & arrayDim >2)
				row = 1;
				constIndNum = constIndNum +1;
				fgetl(fid);
				fgetl(fid);
				tline = fgetl(fid);
			end
			if(arrayDim ==1)
				if(length(str2num(tline)) > 2)
					% just one row
					lineNum = str2num(tline);
					i = 1;
					while(~isempty(lineNum))
						x(i) = lineNum(2);
						lineNum(1)=[];
						lineNum(1)=[];
						i = i+1;	
					end	
				else
					% one number per row
					x(row) = str2num(tline(4:end));
				end

				
			
			elseif(arrayDim == 2)
				if(~transpose)
					x(row,:) = str2num(tline(4:end));
				else
					x(:,row) = str2num(tline(4:end));
				end
			elseif(arrayDim == 3)
				if(~transpose)
					switch indexConst
					case 1
						x(constIndNum,row,:) = str2num(tline(4:end));
					case 2
						x(row,constIndNum,:) = str2num(tline(4:end));
					case 3
						x(row,:,constIndNum) = str2num(tline(4:end));
					end
				else
					switch indexConst
					case 1
						x(constIndNum,:,row) = str2num(tline(4:end));
					case 2
						x(:,constIndNum,row) = str2num(tline(4:end));
					case 3
						x(:,row,constIndNum) = str2num(tline(4:end));
					end

				end
			end
			row = row + 1;
		end
	end
end
end
fclose(fid);
