function create_TSP(N,name)
%---------------------------------------------------------------------
% creates TSP-problem with N cities.
% Input:       
%                N - number of cities
%             name - name of problem
%
% Output:      
%         name.mat - matlab file with distances and positions.
%         name.dat - ampl file with distances.
%
% For example: create_TSP(20,'test') will create test.mat and a test.dat
%---------------------------------------------------------------------

% x- and y-positions for the cities
x = 100*rand(N,1);
y = 100*rand(N,1);
pos = [x,y];

% distances between cities
for i=1:N
    for j=1:N
        if i==j
            c(i,j) = 1000;
        else
            c(i,j) = sqrt((x(i)-x(j))^2 + (y(i)-y(j))^2);
        end
    end
end

% save ampl-file
fileName = [name '.dat'];
fid = fopen(fileName,'w');
AMPLmatrix(fid,'c',c);
AMPLscalarint(fid,'N',N);
fclose(fid);

% save matlab-file
filename = [name '.mat'];
save(filename,'pos','c');