function l = plot_TSP(x,problem,num)
%---------------------------------------------------------------------
% function that plots a solution x given a TSP defined by the problem file.
% Input:
%           x - N*N binary matrix with a solution to the TSP
%     problem - the name of the matlab file defining the problem. 
%               For example 'TSP_small.mat'. 
%         num - value 1 if the plot should write out the numbers of
%               each node in the graph. 0 otherwise.
% Output:
%           l - length of the route
%----------------------------------------------------------------------
% loads the problem instance
load(problem)
N = size(x,1);
l = 0;

% plots the solution
hold on
plot(pos(:,1), pos(:,2),'ok','Linewidth',2,'MarkerSize',10);
for i = 1:N-1
    if num==1
        text(pos(i,1),pos(i,2)+4,num2str(i));
    end
    for j=i+1:N
        % if the variable has value 1, plot a line
        if x(i,j)==1
            plot([pos(i,1) pos(j,1)],[pos(i,2),pos(j,2)],'Linewidth',2);
            l = l + c(i,j);
        % if the variable har a fractional value, plot a dotted line
        elseif x(i,j)>0
            plot([pos(i,1) pos(j,1)],[pos(i,2),pos(j,2)],'-.','Linewidth',2);
            l = l + x(i,j)*c(i,j);
        end
    end
end
if num==1
    text(pos(N,1),pos(N,2)+4,num2str(N));
end
hold off
